# Pipupgui
A simple GUI convenience tool that gives the user control over upgrading pip packages.
## Features:
Pip upgrade all - mass upgrade packages, including pip itself.

Banning Packages - Remove a package from the upgrade queue forever until you unban it.

## Installation
```
pip install pipupgui
```

To Run:
in your project folder / venv run:
```
pipupgui
```


Currently supports windows only

Coming soon:
- specific version control
- macOS support
- args for no-gui, upgrade all, -ban <package>
